/// <reference types="node" />
import pgPromise from 'pg-promise';
import { dataStructures } from '@liskhq/lisk-utils';
export interface DelegateWithVotes {
    readonly address: Buffer;
    readonly votes: bigint;
}
interface Block {
    readonly version: number;
    readonly height: number;
    readonly timestamp: number;
    readonly previousBlock?: string;
    readonly numberOfTransactions: number;
    readonly totalAmount: string;
    readonly totalFee: string;
    readonly reward: string;
    readonly payloadLength: number;
    readonly payloadHash: Buffer;
    readonly generatorPublicKey: Buffer;
    readonly blockSignature: Buffer;
}
export interface LegacyAccount {
    readonly address: string;
    readonly publicKey: Buffer | null;
    readonly secondPublicKey: Buffer | null;
    readonly balance: string;
    readonly isDelegate: number;
    readonly username: string;
    readonly secondSignature: number;
    readonly multimin: number;
    readonly vote: string;
    readonly incomingTxCount: number;
    readonly outgoingTxCount: number;
}
export interface Account {
    readonly address: Buffer;
    readonly token: {
        readonly balance: bigint;
    };
    readonly sequence: {
        readonly nonce: bigint;
    };
    readonly keys: {
        readonly mandatoryKeys: Buffer[];
        readonly optionalKeys: Buffer[];
        readonly numberOfSignatures: number;
    };
    readonly dpos: {
        readonly delegate: {
            readonly username: string;
            readonly pomHeights: number[];
            readonly consecutiveMissedBlocks: number;
            readonly lastForgedHeight: number;
            readonly isBanned: boolean;
            readonly totalVotesReceived: bigint;
        };
        readonly sentVotes: {
            readonly delegateAddress: Buffer;
            readonly amount: bigint;
        }[];
        readonly unlocking: {
            readonly delegateAddress: Buffer;
            readonly amount: bigint;
            readonly unvoteHeight: number;
        }[];
    };
}
export declare const getBlockBytes: (block: Block) => Buffer;
export declare const accountDefaultProps: {
    token: {
        balance: bigint;
    };
    sequence: {
        nonce: bigint;
    };
    dpos: {
        delegate: {
            lastForgedHeight: number;
            username: string;
            pomHeights: never[];
            consecutiveMissedBlocks: number;
            isBanned: boolean;
            totalVotesReceived: bigint;
        };
        sentVotes: never[];
        unlocking: never[];
    };
    keys: {
        mandatoryKeys: never[];
        optionalKeys: never[];
        numberOfSignatures: number;
    };
};
export declare const migrateAddressForAccount: (legacyAccount: LegacyAccount) => {
    legacyAddress: Buffer;
    newAddress: Buffer;
};
export declare const migrateLegacyAccount: ({ db, legacyAccount, snapshotHeight, accountsMap, delegatesMap, legacyAddressMap, }: {
    db: pgPromise.IDatabase<any, import("pg-promise/typescript/pg-subset").IClient>;
    legacyAccount: LegacyAccount;
    accountsMap: dataStructures.BufferMap<Account>;
    delegatesMap: dataStructures.BufferMap<DelegateWithVotes>;
    legacyAddressMap: dataStructures.BufferMap<Buffer>;
    snapshotHeight: number;
}) => Promise<void>;
export declare const sortByVotesReceived: (a: DelegateWithVotes, b: DelegateWithVotes) => number;
export declare const sortAccounts: (a: Account, b: Account) => number;
interface createGenesisBlockFromStorageParams {
    readonly db: pgPromise.IDatabase<any>;
    readonly snapshotHeight: number;
    readonly epochTime: string;
}
export declare const createGenesisBlockFromStorage: ({ db, snapshotHeight, epochTime, }: createGenesisBlockFromStorageParams) => Promise<Record<string, unknown>>;
export declare const writeGenesisBlock: (genesisBlock: Record<string, unknown>, filePath: string) => void;
export {};
